@@ -1,4 +1,4 @@
-/*BINFMTC: ilistcreate.c log.c -lncurses
+/*
  test code for ilistcreate.c
  */
 #include <stdlib.h>
@@ -8,10 +8,9 @@
 #include <assert.h>
 #include "ilist.h"
 
-const char* ilist_PRGNAME="testcode";
+const char *ilist_PRGNAME = "testcode";
 
-int main()
-{
-  ilist_outofmemory("hello world\n");
-  return 0;
+int main() {
+	ilist_outofmemory("hello world\n");
+	return 0;
 }
